<?php

namespace Modules\Qc\Http\Controllers;

use Exception;
use Illuminate\Support\Facades\Auth;
use Illuminate\Contracts\Support\Renderable;
use Illuminate\Http\Request;
use Illuminate\Routing\Controller;
use Modules\Qc\Entities\ElectricalConductivityCheckListData;
use Modules\Qc\Entities\ElectricalConductivityCheckListHeader;

class ElectricalConductivityCheckListDataController extends Controller
{
    public function save(Request $request)
    {
        try {
            $rec = new ElectricalConductivityCheckListHeader();
            $rec->reference_no = $request->get('reference_no');
            $rec->customer_order_plan_data_id = $request->get('customer_order_plan_data_id');
            $rec->product_primary_id = $request->get('product_primary_id');
            $rec->date = $request->get('date');
            $rec->factory = $request->get('factory');
            $rec->item = $request->get('item');
            $rec->quantity = $request->get('quantity');
            $rec->method = $request->get('method');
            $rec->user_id = Auth::user()->id;
            if ($rec->save()) {
                $rec_arr = $request->get("ec_data");
                for ($i = 0; $i < count($rec_arr); $i++) {
                    $ecData = json_decode($rec_arr[$i]);

                    $rec_data = new ElectricalConductivityCheckListData();
                    $rec_data->electrical_conductivity_id = $rec->electrical_conductivity_id;
                    $rec_data->hour = $ecData->hour;
                    $rec_data->ec_unit = $ecData->ec_unit;
                    $rec_data->color = $ecData->color;
                    $rec_data->remarks = $ecData->remarks;
                    $rec_data->save();
                }
            }
            $responseBody = $this->responseBody(true, "ElectricalConductivityCheckListDataController", "saved", true);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "ElectricalConductivityCheckListDataController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }

    public function update(Request $request, $id)
    {

        try {

            if ($this->delete($id)) {
                $rec = ElectricalConductivityCheckListHeader::find($id);
                $rec->reference_no = $request->get('reference_no');
                $rec->customer_order_plan_data_id = $request->get('customer_order_plan_data_id');
                $rec->product_primary_id = $request->get('product_primary_id');
                $rec->date = $request->get('date');
                $rec->factory = $request->get('factory');
                $rec->item = $request->get('item');
                $rec->quantity = $request->get('quantity');
                $rec->method = $request->get('method');
                $rec->update();

                $rec_arr = $request->get("ec_data");
                if ($rec_arr) {
                    for ($i = 0; $i < count($rec_arr); $i++) {
                        $ecData = json_decode($rec_arr[$i]);
                        $rec_data = new ElectricalConductivityCheckListData();
                        $rec_data->electrical_conductivity_id = $rec->electrical_conductivity_id;
                        $rec_data->hour = $ecData->hour;
                        $rec_data->ec_unit = $ecData->ec_unit;
                        $rec_data->color = $ecData->color;
                        $rec_data->remarks = $ecData->remarks;
                        $rec_data->save();
                    }
                }
            }

            $responseBody = $this->responseBody(true, "ElectricalConductivityCheckListDataController", "update", true);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "ElectricalConductivityCheckListDataController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }

    public function delete($id)
    {
        try {
            $rec_data = ElectricalConductivityCheckListData::where('electrical_conductivity_id', '=', $id)->get();
            foreach ($rec_data as $data) {
                $data->delete();
            }
            return true;
        } catch (Exception $exception) {
            return false;
        }
    }

    public function getEcData($id)
    {
        try {
            $recordHead = ElectricalConductivityCheckListHeader::find($id);
            $recordData = ElectricalConductivityCheckListData::where('electrical_conductivity_id', '=', $id)->get();

            $recordHead->request_data = $recordData;

            $responseBody = $this->responseBody(true, "ElectricalConductivityCheckListDataController", "getEcData", $recordHead);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "ElectricalConductivityCheckListDataController", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }


    /**
     * responseBody
     * This is used to create response.
     * @param success This is the paramter require boolean
     * @param name This is the paramter require ui table name
     * @param message This is the paramter require message content
     * @param result This is the paramter require result as some of data to return client
     * @return Json This returns as response.
     */
    private function responseBody($success, $name, $message, $result)
    {
        $body = [
            "success" => $success,
            "message" => $message,
            "name" => $name,
            "result" => $result
        ];
        return $body;
    }
}
